deploy_stake_table

Function deploy_stake_table 

pub async fn deploy_stake_table(
    args: &DeployerArgs<impl Provider + WalletProvider>,
    version: StakeTableContractVersion,
    contracts: &mut Contracts,
) -> Result<()>
Deploys the contract suite up to and including the requested stake table version, recording addresses in contracts.